From: ccaulfield@sourceware.org <ccaulfield@sourceware.org>
To: lvm-devel@redhat.com
Subject: LVM2 ./WHATS_NEW daemons/clvmd/clvmd.c
Date: 24 Mar 2009 11:49:16 -0000 [thread overview]
Message-ID: <20090324114916.2279.qmail@sourceware.org> (raw)
CVSROOT: /cvs/lvm2
Module name: LVM2
Changes by: ccaulfield at sourceware.org 2009-03-24 11:49:16
Modified files:
. : WHATS_NEW
daemons/clvmd : clvmd.c
Log message:
Block SIGINT & SIGTERM in clvmd subthreads so they don't delay shutdown.
Patch from Xinwei Hu, Thanks
Patches:
http://sourceware.org/cgi-bin/cvsweb.cgi/LVM2/WHATS_NEW.diff?cvsroot=lvm2&r1=1.1071&r2=1.1072
http://sourceware.org/cgi-bin/cvsweb.cgi/LVM2/daemons/clvmd/clvmd.c.diff?cvsroot=lvm2&r1=1.55&r2=1.56
--- LVM2/WHATS_NEW 2009/03/23 22:57:27 1.1071
+++ LVM2/WHATS_NEW 2009/03/24 11:49:15 1.1072
@@ -1,5 +1,6 @@
Version 2.02.46 -
================================
+ Block SIGTERM & SIGINT in clvmd subthreads.
Detect and conditionally wipe swapspace signatures in pvcreate.
Fix maximal volume count check for snapshots if max_lv set for volume group.
Fix lvcreate to remove cow volume if the snapshot creation fails.
--- LVM2/daemons/clvmd/clvmd.c 2009/02/22 22:11:58 1.55
+++ LVM2/daemons/clvmd/clvmd.c 2009/03/24 11:49:15 1.56
@@ -372,9 +372,11 @@
signal(SIGHUP, sighup_handler);
signal(SIGPIPE, SIG_IGN);
/* Block SIGUSR2 in the main process */
sigemptyset(&ss);
sigaddset(&ss, SIGUSR2);
+ sigaddset(&ss, SIGINT);
+ sigaddset(&ss, SIGTERM);
sigprocmask(SIG_BLOCK, &ss, NULL);
/* Initialise the LVM thread variables */
@@ -669,6 +671,11 @@
{
DEBUGLOG("Using timeout of %d seconds\n", cmd_timeout);
+ sigset_t ss;
+ sigemptyset(&ss);
+ sigaddset(&ss, SIGINT);
+ sigaddset(&ss, SIGTERM);
+ pthread_sigmask(SIG_UNBLOCK, &ss, NULL);
/* Main loop */
while (!quit) {
fd_set in;
next reply other threads:[~2009-03-24 11:49 UTC|newest]
Thread overview: 32+ messages / expand[flat|nested] mbox.gz Atom feed top
2009-03-24 11:49 ccaulfield [this message]
-- strict thread matches above, loose matches on Subject: below --
2012-02-28 11:06 LVM2 ./WHATS_NEW daemons/clvmd/clvmd.c zkabelac
2012-02-28 9:58 zkabelac
2012-02-28 9:53 zkabelac
2012-02-27 11:26 zkabelac
2012-02-27 9:58 zkabelac
2011-10-11 9:54 zkabelac
2011-10-11 9:26 zkabelac
2011-09-16 14:40 mbroz
2011-08-11 12:57 mbroz
2011-06-28 13:42 zkabelac
2011-03-30 12:36 zkabelac
2011-03-08 22:48 zkabelac
2011-03-08 13:27 mbroz
2010-12-13 10:49 prajnoha
2010-12-01 12:41 zkabelac
2010-12-01 10:46 zkabelac
2010-04-06 15:29 ccaulfield
2010-02-02 8:54 ccaulfield
2009-10-12 8:33 ccaulfield
2009-09-01 9:48 ccaulfield
2009-08-13 10:39 ccaulfield
2008-11-21 13:48 ccaulfield
2008-06-13 7:44 ccaulfield
2008-05-09 9:59 ccaulfield
2008-03-28 12:58 ccaulfield
2008-03-17 9:38 ccaulfield
2008-02-15 14:12 meyering
2007-11-15 10:16 pcaulfield
2007-03-29 13:59 pcaulfield
2006-12-11 13:48 pcaulfield
2006-11-30 9:44 pcaulfield
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20090324114916.2279.qmail@sourceware.org \
--to=ccaulfield@sourceware.org \
--cc=lvm-devel@redhat.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -372,9 +372,11 @@
signal(SIGHUP, sighup_handler);
signal(SIGPIPE, SIG_IGN);
- /* Block SIGUSR2 in the main process */
+ /* Block SIGUSR2/SIGINT/SIGTERM in process */
sigemptyset(&ss);
sigaddset(&ss, SIGUSR2);
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.